@@ -4,7 +4,7 @@ import os
 import json
 
 import attr
-from bunch import Bunch
+from munch import Munch
 from jinja2 import Template
 from pkg_resources import resource_filename
 from twisted.logger import Logger
@@ -41,10 +41,10 @@ class GrafanaDashboardBuilder(object):
         folder_id = folder and folder.get('id') or None
 
         # Get dashboard if already exists
-        dashboard_data = self.grafana_api.get_dashboard(name=dashboard_name)
+        dashboard_data = self.grafana_api.get_dashboard(dashboard_name)
 
         # Debugging
-        #print 'dashboard_data:'; pprint(dashboard_data)
+        # from pprint import pprint; print('dashboard_data:'); pprint(dashboard_data)
 
         # Wrap everything into convenience object
         dashboard = GrafanaDashboard(
@@ -297,7 +297,7 @@ class GrafanaDashboardBuilder(object):
 class GrafanaDashboard(object):
 
     def __init__(self, channel=None, uid=None, title='default', datasource='default', folder_id=None, dashboard_data=None):
-        self.channel = channel or Bunch()
+        self.channel = channel or Munch()
         self.dashboard_uid = uid
         self.dashboard_title = title
         self.datasource = datasource
