@@ -8,7 +8,7 @@ from kotori.daq.services import MultiServiceMixin
 from kotori.daq.graphing.grafana.api import GrafanaApi
 from kotori.daq.graphing.grafana.dashboard import GrafanaDashboardBuilder, GrafanaDashboardModel
 from kotori.daq.graphing.grafana.service import DashboardRefreshTamingService
-from kotori.util.common import KeyCache, SmartBunch
+from kotori.util.common import KeyCache, SmartMunch
 
 log = Logger()
 
@@ -28,9 +28,10 @@ class GrafanaManager(MultiService, MultiServiceMixin):
         if not 'port' in self.config['grafana']:
             self.config['grafana']['port'] = '3000'
 
-        name = self.__class__.__name__
+        self.name = 'grafana-manager-{realm}-{id}'.format(realm=self.channel.get('realm'), id=str(id(self)))
+
         log.info('Starting GrafanaManager "{}". grafana={}:{}'.format(
-            name,
+            self.name,
             self.config['grafana']['host'],
             self.config['grafana']['port']))
 
@@ -99,10 +100,11 @@ class GrafanaManager(MultiService, MultiServiceMixin):
             name = topology.node
 
         # Derive dashboard uid and name from topology information
-        identity = SmartBunch(
-            #uid=u'{realm}-{name}-instant'.format(realm=realm, name=name),
-            name=u'{realm}-{name}'.format(realm=realm, name=name),
-            title=u'{realm}-{name}'.format(realm=realm, name=name),
+        label = u'{realm}-{name}'.format(realm=realm, name=name)
+        identity = SmartMunch(
+            uid=label,
+            name=label,
+            title=label,
             # TODO: Use real title after fully upgrading to new Grafana API (i.e. don't use get-by-slug anymore!)
             #title=u'Raw data for realm={realm} network={network}'.format(realm=realm, network=network),
         )
@@ -139,7 +141,7 @@ class GrafanaManager(MultiService, MultiServiceMixin):
 
         # Define Grafana dashboard model
         model = GrafanaDashboardModel(
-            #uid=dashboard_identity.uid,
+            uid=dashboard_identity.uid,
             name=dashboard_identity.name,
             title=dashboard_identity.title,
             datasource=datasource_name,
@@ -204,7 +206,7 @@ class GrafanaManager(MultiService, MultiServiceMixin):
 
         for dashboard_meta in dashboard_list:
 
-            dashboard_meta = SmartBunch.bunchify(dashboard_meta)
+            dashboard_meta = SmartMunch.munchify(dashboard_meta)
             #print dashboard_meta.prettify()
 
             whoami = u'title="{title}", uid="{uid}"'.format(title=dashboard_meta['title'], uid=dashboard_meta['uid'])
@@ -212,7 +214,7 @@ class GrafanaManager(MultiService, MultiServiceMixin):
             # Request dashboard by uid
             dashboard_uid = dashboard_meta['uid']
             response = self.grafana_api.get_dashboard_by_uid(dashboard_uid)
-            response = SmartBunch.bunchify(response)
+            response = SmartMunch.munchify(response)
 
             # Get effective dashboard information from response
             folder_id = response.meta.folderId
