@@ -4,7 +4,7 @@ import time
 import json
 
 import arrow
-from bunch import Bunch
+from munch import Munch
 from cornice.util import to_list
 from twisted.logger import Logger, LogLevel
 from twisted.internet import reactor
@@ -34,7 +34,7 @@ class MqttInfluxGrafanaService(MultiService, MultiServiceMixin):
 
         # TODO: Make subsystems dynamic
         self.subsystems = ['channel', 'graphing', 'strategy']
-        self.channel = channel or Bunch(realm=None, subscriptions=[])
+        self.channel = channel or Munch(realm=None, subscriptions=[])
         self.graphing = to_list(graphing)
         self.strategy = strategy
 
@@ -45,25 +45,34 @@ class MqttInfluxGrafanaService(MultiService, MultiServiceMixin):
         self.log(log.info, u'Bootstrapping')
         self.settings = self.parent.settings
 
-        # Optionally register subsystem component as child service
+        # Register subsystem components as child services.
         for subsystem in self.subsystems:
             if hasattr(self, subsystem):
-                subsystem_service = getattr(self, subsystem)
-                if isinstance(subsystem_service, Service):
-                    log.info('Registering subsystem component "{subsystem}" as service', subsystem=subsystem)
-                    self.registerService(subsystem_service)
+                subsystem_services = to_list(getattr(self, subsystem))
+                for service in subsystem_services:
+                    if isinstance(service, Service):
+                        log.info('Registering subsystem component "{subsystem}" as service at name "{name}"', subsystem=subsystem, name=service.name)
+                        self.registerService(service)
 
         # Configure metrics to be collected each X seconds
         metrics_interval = int(self.channel.get('metrics_logger_interval', 60))
-        self.metrics = Bunch(tx_count=0, starttime=time.time(), interval=metrics_interval)
+        self.metrics = Munch(tx_count=0, starttime=time.time(), interval=metrics_interval)
+
+        # Check if application/channel has an associated MQTT broker definition.
+        # When present, use those connection details instead of the global ones.
+        settings_key = f"{self.channel.realm}:mqtt"
+        if settings_key in self.settings:
+            mqtt_settings = self.settings[settings_key]
+        else:
+            mqtt_settings = self.settings["mqtt"]
 
         subscriptions = read_list(self.channel.mqtt_topics)
         self.mqtt_service = MqttAdapter(
             name          = u'mqtt-' + self.channel.realm,
-            broker_host   = self.settings.mqtt.host,
-            broker_port   = int(self.settings.mqtt.port),
-            broker_username = self.settings.mqtt.username,
-            broker_password = self.settings.mqtt.password,
+            broker_host   = mqtt_settings.host,
+            broker_port   = int(mqtt_settings.get("port", 1883)),
+            broker_username = mqtt_settings.get("username"),
+            broker_password = mqtt_settings.get("password"),
             callback      = self.mqtt_receive,
             subscriptions = subscriptions)
 
