@@ -4,7 +4,7 @@ import os
 import logging
 from configparser import ConfigParser
 from glob import glob
-from bunch import Bunch
+from munch import Munch
 from cornice.util import to_list
 
 log = logging.getLogger()
@@ -30,7 +30,7 @@ def get_configuration(*args):
     config_files += [os.path.expanduser('~/.kotori.ini')]
     config_files += list(args)
     log.info('Requested configuration files: {}'.format(make_list(config_files)))
-    config, used = read_config(config_files, kind=Bunch)
+    config, used = read_config(config_files, kind=Munch)
     if config:
         if 'main' in config and 'include' in config.main:
             includes = read_list(config.main.include)
@@ -40,8 +40,8 @@ def get_configuration(*args):
                 else:
                     config_files.append(include)
             log.info('Expanded configuration files:  {}'.format(make_list(config_files)))
-            config, used = read_config(config_files, kind=Bunch)
-        log.info('Used configuration files:      {}'.format(make_list(used)))
+            config, used = read_config(config_files, kind=Munch)
+        log.info('Effective configuration files: {}'.format(make_list(used)))
         return config
     else:
         msg = u'Could not read settings from configuration files: {}'.format(config_files)
@@ -86,7 +86,7 @@ def make_list(items, separator=u', '):
 def apply_default_settings(settings):
 
     # MQTT setting defaults
-    settings.mqtt.setdefault('host', u'localhost')
-    settings.mqtt.setdefault('port', u'1883')
-    settings.mqtt.setdefault('debug', u'false')
-
+    if "mqtt" in settings:
+        settings.mqtt.setdefault('host', u'localhost')
+        settings.mqtt.setdefault('port', u'1883')
+        settings.mqtt.setdefault('debug', u'false')
