@@ -10,11 +10,12 @@ import logging
 import pytest_twisted
 
 from kotori import KotoriBootloader
-from test.util import boot_kotori
+from test.util import boot_kotori, sleep
 from test.settings.mqttkit import influx_sensors, influx_events, grafana
 
 logger = logging.getLogger(__name__)
 
+STARTUP_DELAY = 1.5
 
 # Disable ellipsis truncation
 # https://stackoverflow.com/questions/19171554/preventing-truncation-of-long-strings-in-pytest/60321834#60321834
@@ -36,7 +37,11 @@ def create_machinery(config, scope="package"):
         result = boot_kotori(config)
         assert isinstance(result, KotoriBootloader)
 
-        #pytest_twisted.blockon(result)
+        logger.info(f"Delaying for {STARTUP_DELAY} seconds to wait for the machinery to start")
+        waiter = sleep(STARTUP_DELAY)
+        pytest_twisted.blockon(waiter)
+
+        logger.info('Machinery is ready')
         yield result
 
     return machinery
@@ -46,5 +51,6 @@ machinery = create_machinery('./etc/test/main.ini')
 create_influxdb = influx_sensors.make_create_db()
 reset_influxdb = influx_sensors.make_reset_measurement()
 reset_grafana = grafana.make_reset()
-
 reset_influxdb_events = influx_events.make_reset_measurement()
+
+machinery_basic = create_machinery('./etc/test/basic.ini')
